# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/predict/predict-buffer/predict-buffer-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.predict.predict_api import predict_api_service_pb2 as cogneed__protos_dot_predict_dot_predict__api_dot_predict__api__service__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/predict/predict-buffer/predict-buffer-service.proto',
  package='ai.cogneed.api.predict.predictbuffer',
  syntax='proto3',
  serialized_options=_b('\n$ai.cogneed.api.predict.predictbufferP\001'),
  serialized_pb=_b('\nBcogneed-protos/predict/predict-buffer/predict-buffer-service.proto\x12$ai.cogneed.api.predict.predictbuffer\x1a<cogneed-protos/predict/predict-api/predict-api-service.proto\"{\n\x12PredictionResponse\x12\x13\n\x0bnum_classes\x18\x01 \x01(\x05\x12\x18\n\x10prediction_index\x18\x02 \x01(\x05\x12\x13\n\x0bprobability\x18\x03 \x01(\x02\x12\x12\n\nmodel_name\x18\x04 \x01(\t\x12\r\n\x05minor\x18\x05 \x01(\x03\"\xd7\x01\n\x15PredictBufferResponse\x12N\n\nprediction\x18\x01 \x01(\x0b\x32\x38.ai.cogneed.api.predict.predictbuffer.PredictionResponseH\x00\x12P\n\rno_prediction\x18\x02 \x01(\x0b\x32\x37.ai.cogneed.api.predict.predictapi.NoPredictionResponseH\x00\x12\x11\n\x07\x66\x61ilure\x18\x03 \x01(\tH\x00\x42\t\n\x07\x63ontent\"u\n\x14PredictBufferRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\x12\r\n\x05major\x18\x03 \x01(\t\x12\x18\n\x10start_mfcc_index\x18\x04 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\x32\x9b\x01\n\x14PredictBufferService\x12\x82\x01\n\x07predict\x12:.ai.cogneed.api.predict.predictbuffer.PredictBufferRequest\x1a;.ai.cogneed.api.predict.predictbuffer.PredictBufferResponseB(\n$ai.cogneed.api.predict.predictbufferP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_predict_dot_predict__api_dot_predict__api__service__pb2.DESCRIPTOR,])




_PREDICTIONRESPONSE = _descriptor.Descriptor(
  name='PredictionResponse',
  full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.num_classes', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_index', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.prediction_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probability', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.probability', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.model_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minor', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.minor', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=293,
)


_PREDICTBUFFERRESPONSE = _descriptor.Descriptor(
  name='PredictBufferResponse',
  full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse.prediction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_prediction', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse.no_prediction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse.failure', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=296,
  serialized_end=511,
)


_PREDICTBUFFERREQUEST = _descriptor.Descriptor(
  name='PredictBufferRequest',
  full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.major', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_mfcc_index', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.start_mfcc_index', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=630,
)

_PREDICTBUFFERRESPONSE.fields_by_name['prediction'].message_type = _PREDICTIONRESPONSE
_PREDICTBUFFERRESPONSE.fields_by_name['no_prediction'].message_type = cogneed__protos_dot_predict_dot_predict__api_dot_predict__api__service__pb2._NOPREDICTIONRESPONSE
_PREDICTBUFFERRESPONSE.oneofs_by_name['content'].fields.append(
  _PREDICTBUFFERRESPONSE.fields_by_name['prediction'])
_PREDICTBUFFERRESPONSE.fields_by_name['prediction'].containing_oneof = _PREDICTBUFFERRESPONSE.oneofs_by_name['content']
_PREDICTBUFFERRESPONSE.oneofs_by_name['content'].fields.append(
  _PREDICTBUFFERRESPONSE.fields_by_name['no_prediction'])
_PREDICTBUFFERRESPONSE.fields_by_name['no_prediction'].containing_oneof = _PREDICTBUFFERRESPONSE.oneofs_by_name['content']
_PREDICTBUFFERRESPONSE.oneofs_by_name['content'].fields.append(
  _PREDICTBUFFERRESPONSE.fields_by_name['failure'])
_PREDICTBUFFERRESPONSE.fields_by_name['failure'].containing_oneof = _PREDICTBUFFERRESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['PredictionResponse'] = _PREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['PredictBufferResponse'] = _PREDICTBUFFERRESPONSE
DESCRIPTOR.message_types_by_name['PredictBufferRequest'] = _PREDICTBUFFERREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictionResponse = _reflection.GeneratedProtocolMessageType('PredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_buffer.predict_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictbuffer.PredictionResponse)
  ))
_sym_db.RegisterMessage(PredictionResponse)

PredictBufferResponse = _reflection.GeneratedProtocolMessageType('PredictBufferResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTBUFFERRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_buffer.predict_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictbuffer.PredictBufferResponse)
  ))
_sym_db.RegisterMessage(PredictBufferResponse)

PredictBufferRequest = _reflection.GeneratedProtocolMessageType('PredictBufferRequest', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTBUFFERREQUEST,
  __module__ = 'cogneed_protos.predict.predict_buffer.predict_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictbuffer.PredictBufferRequest)
  ))
_sym_db.RegisterMessage(PredictBufferRequest)


DESCRIPTOR._options = None

_PREDICTBUFFERSERVICE = _descriptor.ServiceDescriptor(
  name='PredictBufferService',
  full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=633,
  serialized_end=788,
  methods=[
  _descriptor.MethodDescriptor(
    name='predict',
    full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferService.predict',
    index=0,
    containing_service=None,
    input_type=_PREDICTBUFFERREQUEST,
    output_type=_PREDICTBUFFERRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTBUFFERSERVICE)

DESCRIPTOR.services_by_name['PredictBufferService'] = _PREDICTBUFFERSERVICE

# @@protoc_insertion_point(module_scope)
