# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/trainui/tasks.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api.trainui import sentence_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/trainui/tasks.proto',
  package='ai.cogneed.api.trainui.tasks',
  syntax='proto3',
  serialized_options=_b('\n\034ai.cogneed.api.trainui.tasksP\001'),
  serialized_pb=_b('\n1cogneed-protos/ai/cogneed/api/trainui/tasks.proto\x12\x1c\x61i.cogneed.api.trainui.tasks\x1a\x34\x63ogneed-protos/ai/cogneed/api/trainui/sentence.proto\"+\n\x08Progress\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\x05\x12\x0e\n\x06target\x18\x02 \x01(\x05\":\n\x0bTaskRequest\x12\x15\n\ruse_case_uuid\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t2\xd3\x01\n\x0cTasksService\x12\x61\n\x0cget_progress\x12).ai.cogneed.api.trainui.tasks.TaskRequest\x1a&.ai.cogneed.api.trainui.tasks.Progress\x12`\n\x08get_next\x12).ai.cogneed.api.trainui.tasks.TaskRequest\x1a).ai.cogneed.api.trainui.sentence.SentenceB \n\x1c\x61i.cogneed.api.trainui.tasksP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2.DESCRIPTOR,])




_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='ai.cogneed.api.trainui.tasks.Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='ai.cogneed.api.trainui.tasks.Progress.current', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='ai.cogneed.api.trainui.tasks.Progress.target', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=180,
)


_TASKREQUEST = _descriptor.Descriptor(
  name='TaskRequest',
  full_name='ai.cogneed.api.trainui.tasks.TaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.trainui.tasks.TaskRequest.use_case_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.tasks.TaskRequest.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=240,
)

DESCRIPTOR.message_types_by_name['Progress'] = _PROGRESS
DESCRIPTOR.message_types_by_name['TaskRequest'] = _TASKREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Progress = _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), dict(
  DESCRIPTOR = _PROGRESS,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.tasks_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.tasks.Progress)
  ))
_sym_db.RegisterMessage(Progress)

TaskRequest = _reflection.GeneratedProtocolMessageType('TaskRequest', (_message.Message,), dict(
  DESCRIPTOR = _TASKREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.tasks_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.tasks.TaskRequest)
  ))
_sym_db.RegisterMessage(TaskRequest)


DESCRIPTOR._options = None

_TASKSSERVICE = _descriptor.ServiceDescriptor(
  name='TasksService',
  full_name='ai.cogneed.api.trainui.tasks.TasksService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=243,
  serialized_end=454,
  methods=[
  _descriptor.MethodDescriptor(
    name='get_progress',
    full_name='ai.cogneed.api.trainui.tasks.TasksService.get_progress',
    index=0,
    containing_service=None,
    input_type=_TASKREQUEST,
    output_type=_PROGRESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_next',
    full_name='ai.cogneed.api.trainui.tasks.TasksService.get_next',
    index=1,
    containing_service=None,
    input_type=_TASKREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2._SENTENCE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TASKSSERVICE)

DESCRIPTOR.services_by_name['TasksService'] = _TASKSSERVICE

# @@protoc_insertion_point(module_scope)
