# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.modelconfig import model_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2


class ModelServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.create = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/create',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Create.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.FromString,
        )
    self.list = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/list',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.List.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListResponse.FromString,
        )
    self.read = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/read',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Model.FromString,
        )
    self.upgrade = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/upgrade',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
        )
    self.startTraining = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/startTraining',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.FromString,
        )
    self.deploy = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/deploy',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.FromString,
        )
    self.markAsTrained = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/markAsTrained',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.FromString,
        )


class ModelServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def list(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def read(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def upgrade(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def startTraining(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def deploy(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def markAsTrained(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ModelServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'create': grpc.unary_unary_rpc_method_handler(
          servicer.create,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Create.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.SerializeToString,
      ),
      'list': grpc.unary_unary_rpc_method_handler(
          servicer.list,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.List.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListResponse.SerializeToString,
      ),
      'read': grpc.unary_unary_rpc_method_handler(
          servicer.read,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Model.SerializeToString,
      ),
      'upgrade': grpc.unary_unary_rpc_method_handler(
          servicer.upgrade,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
      ),
      'startTraining': grpc.unary_unary_rpc_method_handler(
          servicer.startTraining,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.SerializeToString,
      ),
      'deploy': grpc.unary_unary_rpc_method_handler(
          servicer.deploy,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.SerializeToString,
      ),
      'markAsTrained': grpc.unary_unary_rpc_method_handler(
          servicer.markAsTrained,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.modelconfig.model.ModelService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
