# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/common/g711.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/common/g711.proto',
  package='ai.cogneed.audio.decode.g711',
  syntax='proto3',
  serialized_options=_b('\n\034ai.cogneed.audio.decode.g711P\001'),
  serialized_pb=_b('\n-cogneed-protos/audio-stream/common/g711.proto\x12\x1c\x61i.cogneed.audio.decode.g711*)\n\tG711Codec\x12\r\n\tG711_ULAW\x10\x00\x12\r\n\tG711_ALAW\x10\x01\x42 \n\x1c\x61i.cogneed.audio.decode.g711P\x01\x62\x06proto3')
)

_G711CODEC = _descriptor.EnumDescriptor(
  name='G711Codec',
  full_name='ai.cogneed.audio.decode.g711.G711Codec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='G711_ULAW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G711_ALAW', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=79,
  serialized_end=120,
)
_sym_db.RegisterEnumDescriptor(_G711CODEC)

G711Codec = enum_type_wrapper.EnumTypeWrapper(_G711CODEC)
G711_ULAW = 0
G711_ALAW = 1


DESCRIPTOR.enum_types_by_name['G711Codec'] = _G711CODEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
