# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/predict/predict-eval/predict-eval-api-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/predict/predict-eval/predict-eval-api-service.proto',
  package='ai.cogneed.api.predict.predicteval',
  syntax='proto3',
  serialized_options=_b('\n\"ai.cogneed.api.predict.predictevalP\001'),
  serialized_pb=_b('\nBcogneed-protos/predict/predict-eval/predict-eval-api-service.proto\x12\"ai.cogneed.api.predict.predicteval\"_\n\x0eRequestFailure\x12\x0f\n\x07message\x18\x01 \x01(\t\x12<\n\x04\x63ode\x18\x02 \x01(\x0e\x32..ai.cogneed.api.predict.predicteval.StatusCode\"6\n\x11\x45valuationMetrics\x12\x11\n\tprecision\x18\x01 \x01(\x02\x12\x0e\n\x06recall\x18\x02 \x01(\x02\"w\n\nSetRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0f\n\x07keyword\x18\x02 \x01(\t\x12\x44\n\x05value\x18\x03 \x01(\x0b\x32\x35.ai.cogneed.api.predict.predicteval.EvaluationMetrics\"1\n\nGetRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"u\n\x0bSetResponse\x12\x14\n\nnum_insert\x18\x01 \x01(\x05H\x00\x12\x45\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x32.ai.cogneed.api.predict.predicteval.RequestFailureH\x00\x42\t\n\x07\x63ontent\"\xa8\x01\n\x0bGetResponse\x12G\n\x06result\x18\x01 \x01(\x0b\x32\x35.ai.cogneed.api.predict.predicteval.EvaluationMetricsH\x00\x12\x45\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x32.ai.cogneed.api.predict.predicteval.RequestFailureH\x00\x42\t\n\x07\x63ontent*r\n\nStatusCode\x12\x18\n\x14MODEL_DOES_NOT_EXIST\x10\x00\x12 \n\x1cMODEL_KEYWORD_DOES_NOT_EXIST\x10\x01\x12\x16\n\x12\x42\x41\x44_INSERT_REQUEST\x10\x02\x12\x10\n\x0cSERVER_ERROR\x10\x03\x32\xe4\x01\n\x12PredictEvalService\x12\x66\n\x03get\x12..ai.cogneed.api.predict.predicteval.GetRequest\x1a/.ai.cogneed.api.predict.predicteval.GetResponse\x12\x66\n\x03set\x12..ai.cogneed.api.predict.predicteval.SetRequest\x1a/.ai.cogneed.api.predict.predicteval.SetResponseB&\n\"ai.cogneed.api.predict.predictevalP\x01\x62\x06proto3')
)

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='ai.cogneed.api.predict.predicteval.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODEL_DOES_NOT_EXIST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_KEYWORD_DOES_NOT_EXIST', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_INSERT_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=721,
  serialized_end=835,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
MODEL_DOES_NOT_EXIST = 0
MODEL_KEYWORD_DOES_NOT_EXIST = 1
BAD_INSERT_REQUEST = 2
SERVER_ERROR = 3



_REQUESTFAILURE = _descriptor.Descriptor(
  name='RequestFailure',
  full_name='ai.cogneed.api.predict.predicteval.RequestFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ai.cogneed.api.predict.predicteval.RequestFailure.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='ai.cogneed.api.predict.predicteval.RequestFailure.code', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=201,
)


_EVALUATIONMETRICS = _descriptor.Descriptor(
  name='EvaluationMetrics',
  full_name='ai.cogneed.api.predict.predicteval.EvaluationMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='precision', full_name='ai.cogneed.api.predict.predicteval.EvaluationMetrics.precision', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recall', full_name='ai.cogneed.api.predict.predicteval.EvaluationMetrics.recall', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=257,
)


_SETREQUEST = _descriptor.Descriptor(
  name='SetRequest',
  full_name='ai.cogneed.api.predict.predicteval.SetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.predict.predicteval.SetRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.predicteval.SetRequest.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.cogneed.api.predict.predicteval.SetRequest.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=378,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='ai.cogneed.api.predict.predicteval.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.predict.predicteval.GetRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.predicteval.GetRequest.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=429,
)


_SETRESPONSE = _descriptor.Descriptor(
  name='SetResponse',
  full_name='ai.cogneed.api.predict.predicteval.SetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_insert', full_name='ai.cogneed.api.predict.predicteval.SetResponse.num_insert', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='ai.cogneed.api.predict.predicteval.SetResponse.failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predicteval.SetResponse.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=431,
  serialized_end=548,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='ai.cogneed.api.predict.predicteval.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai.cogneed.api.predict.predicteval.GetResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='ai.cogneed.api.predict.predicteval.GetResponse.failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predicteval.GetResponse.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=551,
  serialized_end=719,
)

_REQUESTFAILURE.fields_by_name['code'].enum_type = _STATUSCODE
_SETREQUEST.fields_by_name['value'].message_type = _EVALUATIONMETRICS
_SETRESPONSE.fields_by_name['failure'].message_type = _REQUESTFAILURE
_SETRESPONSE.oneofs_by_name['content'].fields.append(
  _SETRESPONSE.fields_by_name['num_insert'])
_SETRESPONSE.fields_by_name['num_insert'].containing_oneof = _SETRESPONSE.oneofs_by_name['content']
_SETRESPONSE.oneofs_by_name['content'].fields.append(
  _SETRESPONSE.fields_by_name['failure'])
_SETRESPONSE.fields_by_name['failure'].containing_oneof = _SETRESPONSE.oneofs_by_name['content']
_GETRESPONSE.fields_by_name['result'].message_type = _EVALUATIONMETRICS
_GETRESPONSE.fields_by_name['failure'].message_type = _REQUESTFAILURE
_GETRESPONSE.oneofs_by_name['content'].fields.append(
  _GETRESPONSE.fields_by_name['result'])
_GETRESPONSE.fields_by_name['result'].containing_oneof = _GETRESPONSE.oneofs_by_name['content']
_GETRESPONSE.oneofs_by_name['content'].fields.append(
  _GETRESPONSE.fields_by_name['failure'])
_GETRESPONSE.fields_by_name['failure'].containing_oneof = _GETRESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['RequestFailure'] = _REQUESTFAILURE
DESCRIPTOR.message_types_by_name['EvaluationMetrics'] = _EVALUATIONMETRICS
DESCRIPTOR.message_types_by_name['SetRequest'] = _SETREQUEST
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['SetResponse'] = _SETRESPONSE
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestFailure = _reflection.GeneratedProtocolMessageType('RequestFailure', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTFAILURE,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.RequestFailure)
  ))
_sym_db.RegisterMessage(RequestFailure)

EvaluationMetrics = _reflection.GeneratedProtocolMessageType('EvaluationMetrics', (_message.Message,), dict(
  DESCRIPTOR = _EVALUATIONMETRICS,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.EvaluationMetrics)
  ))
_sym_db.RegisterMessage(EvaluationMetrics)

SetRequest = _reflection.GeneratedProtocolMessageType('SetRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETREQUEST,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.SetRequest)
  ))
_sym_db.RegisterMessage(SetRequest)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

SetResponse = _reflection.GeneratedProtocolMessageType('SetResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.SetResponse)
  ))
_sym_db.RegisterMessage(SetResponse)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)


DESCRIPTOR._options = None

_PREDICTEVALSERVICE = _descriptor.ServiceDescriptor(
  name='PredictEvalService',
  full_name='ai.cogneed.api.predict.predicteval.PredictEvalService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=838,
  serialized_end=1066,
  methods=[
  _descriptor.MethodDescriptor(
    name='get',
    full_name='ai.cogneed.api.predict.predicteval.PredictEvalService.get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='set',
    full_name='ai.cogneed.api.predict.predicteval.PredictEvalService.set',
    index=1,
    containing_service=None,
    input_type=_SETREQUEST,
    output_type=_SETRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTEVALSERVICE)

DESCRIPTOR.services_by_name['PredictEvalService'] = _PREDICTEVALSERVICE

# @@protoc_insertion_point(module_scope)
