# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2
from cogneed_protos.ai.cogneed.api.trainui import record_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2


class RecordServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.create = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/create',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.Create.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.read_audio = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/read_audio',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordAudio.FromString,
        )
    self.read = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/read',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.Record.FromString,
        )
    self.list = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/list',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.ListRecords.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.ListRecordsResponse.FromString,
        )
    self.delete = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/delete',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.updateWindow = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/updateWindow',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.UpdateWindow.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.validate = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/validate',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class RecordServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def read_audio(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def read(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def list(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def updateWindow(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def validate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RecordServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'create': grpc.unary_unary_rpc_method_handler(
          servicer.create,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.Create.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'read_audio': grpc.unary_unary_rpc_method_handler(
          servicer.read_audio,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordAudio.SerializeToString,
      ),
      'read': grpc.unary_unary_rpc_method_handler(
          servicer.read,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.Record.SerializeToString,
      ),
      'list': grpc.unary_unary_rpc_method_handler(
          servicer.list,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.ListRecords.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.ListRecordsResponse.SerializeToString,
      ),
      'delete': grpc.unary_unary_rpc_method_handler(
          servicer.delete,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'updateWindow': grpc.unary_unary_rpc_method_handler(
          servicer.updateWindow,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.UpdateWindow.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'validate': grpc.unary_unary_rpc_method_handler(
          servicer.validate,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.trainui.record.RecordService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
