# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/audio-stream-api/audio-stream-api-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.audio_stream.common import common_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/audio-stream-api/audio-stream-api-service.proto',
  package='ai.cogneed.api.audio.audiostream',
  syntax='proto3',
  serialized_options=_b('\n ai.cogneed.api.audio.audiostreamP\001'),
  serialized_pb=_b('\nKcogneed-protos/audio-stream/audio-stream-api/audio-stream-api-service.proto\x12 ai.cogneed.api.audio.audiostream\x1a/cogneed-protos/audio-stream/common/common.proto\"7\n\x13InitSessionResponse\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\t\",\n\tModelInfo\x12\r\n\x05major\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\"\x9a\x02\n\tAudioBlob\x12\x39\n\naudio_info\x18\x01 \x01(\x0b\x32%.ai.cogneed.cloud.speech.v1.AudioInfo\x12I\n\x12persistence_config\x18\x02 \x01(\x0b\x32-.ai.cogneed.cloud.speech.v1.PersistenceConfig\x12?\n\nmodel_info\x18\x03 \x01(\x0b\x32+.ai.cogneed.api.audio.audiostream.ModelInfo\x12\x11\n\tcall_uuid\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\x12\x12\n\nblob_index\x18\x06 \x01(\x03\x12\x0e\n\x06millis\x18\x07 \x01(\x03\"\x15\n\x13NoDetectionResponse\"\xa1\x01\n\x08Response\x12\x42\n\tdetection\x18\x01 \x01(\x0b\x32-.ai.cogneed.cloud.speech.v1.DetectionResponseH\x00\x12\x46\n\x05\x65mpty\x18\x02 \x01(\x0b\x32\x35.ai.cogneed.api.audio.audiostream.NoDetectionResponseH\x00\x42\t\n\x07\x63ontent\"&\n\x11\x45ndSessionRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\"\x14\n\x12\x45ndSessionResponse2\xec\x02\n\x12StreamAudioService\x12u\n\x0cinit_session\x12..ai.cogneed.cloud.speech.v1.InitSessionRequest\x1a\x35.ai.cogneed.api.audio.audiostream.InitSessionResponse\x12\x65\n\nsend_audio\x12+.ai.cogneed.api.audio.audiostream.AudioBlob\x1a*.ai.cogneed.api.audio.audiostream.Response\x12x\n\x0b\x65nd_session\x12\x33.ai.cogneed.api.audio.audiostream.EndSessionRequest\x1a\x34.ai.cogneed.api.audio.audiostream.EndSessionResponseB$\n ai.cogneed.api.audio.audiostreamP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2.DESCRIPTOR,])




_INITSESSIONRESPONSE = _descriptor.Descriptor(
  name='InitSessionResponse',
  full_name='ai.cogneed.api.audio.audiostream.InitSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.audiostream.InitSessionResponse.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.audio.audiostream.InitSessionResponse.major', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=217,
)


_MODELINFO = _descriptor.Descriptor(
  name='ModelInfo',
  full_name='ai.cogneed.api.audio.audiostream.ModelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.audio.audiostream.ModelInfo.major', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.audio.audiostream.ModelInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=263,
)


_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.api.audio.audiostream.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_info', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.audio_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence_config', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.persistence_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_info', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.model_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.call_uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.blob_index', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='millis', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.millis', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=548,
)


_NODETECTIONRESPONSE = _descriptor.Descriptor(
  name='NoDetectionResponse',
  full_name='ai.cogneed.api.audio.audiostream.NoDetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=571,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='ai.cogneed.api.audio.audiostream.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection', full_name='ai.cogneed.api.audio.audiostream.Response.detection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty', full_name='ai.cogneed.api.audio.audiostream.Response.empty', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.audio.audiostream.Response.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=574,
  serialized_end=735,
)


_ENDSESSIONREQUEST = _descriptor.Descriptor(
  name='EndSessionRequest',
  full_name='ai.cogneed.api.audio.audiostream.EndSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.audiostream.EndSessionRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=737,
  serialized_end=775,
)


_ENDSESSIONRESPONSE = _descriptor.Descriptor(
  name='EndSessionResponse',
  full_name='ai.cogneed.api.audio.audiostream.EndSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=797,
)

_AUDIOBLOB.fields_by_name['audio_info'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._AUDIOINFO
_AUDIOBLOB.fields_by_name['persistence_config'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._PERSISTENCECONFIG
_AUDIOBLOB.fields_by_name['model_info'].message_type = _MODELINFO
_RESPONSE.fields_by_name['detection'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._DETECTIONRESPONSE
_RESPONSE.fields_by_name['empty'].message_type = _NODETECTIONRESPONSE
_RESPONSE.oneofs_by_name['content'].fields.append(
  _RESPONSE.fields_by_name['detection'])
_RESPONSE.fields_by_name['detection'].containing_oneof = _RESPONSE.oneofs_by_name['content']
_RESPONSE.oneofs_by_name['content'].fields.append(
  _RESPONSE.fields_by_name['empty'])
_RESPONSE.fields_by_name['empty'].containing_oneof = _RESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['InitSessionResponse'] = _INITSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ModelInfo'] = _MODELINFO
DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['NoDetectionResponse'] = _NODETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['EndSessionRequest'] = _ENDSESSIONREQUEST
DESCRIPTOR.message_types_by_name['EndSessionResponse'] = _ENDSESSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitSessionResponse = _reflection.GeneratedProtocolMessageType('InitSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.InitSessionResponse)
  ))
_sym_db.RegisterMessage(InitSessionResponse)

ModelInfo = _reflection.GeneratedProtocolMessageType('ModelInfo', (_message.Message,), dict(
  DESCRIPTOR = _MODELINFO,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.ModelInfo)
  ))
_sym_db.RegisterMessage(ModelInfo)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

NoDetectionResponse = _reflection.GeneratedProtocolMessageType('NoDetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _NODETECTIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.NoDetectionResponse)
  ))
_sym_db.RegisterMessage(NoDetectionResponse)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.Response)
  ))
_sym_db.RegisterMessage(Response)

EndSessionRequest = _reflection.GeneratedProtocolMessageType('EndSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.EndSessionRequest)
  ))
_sym_db.RegisterMessage(EndSessionRequest)

EndSessionResponse = _reflection.GeneratedProtocolMessageType('EndSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.EndSessionResponse)
  ))
_sym_db.RegisterMessage(EndSessionResponse)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.api.audio.audiostream.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=800,
  serialized_end=1164,
  methods=[
  _descriptor.MethodDescriptor(
    name='init_session',
    full_name='ai.cogneed.api.audio.audiostream.StreamAudioService.init_session',
    index=0,
    containing_service=None,
    input_type=cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._INITSESSIONREQUEST,
    output_type=_INITSESSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='send_audio',
    full_name='ai.cogneed.api.audio.audiostream.StreamAudioService.send_audio',
    index=1,
    containing_service=None,
    input_type=_AUDIOBLOB,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='end_session',
    full_name='ai.cogneed.api.audio.audiostream.StreamAudioService.end_session',
    index=2,
    containing_service=None,
    input_type=_ENDSESSIONREQUEST,
    output_type=_ENDSESSIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE

# @@protoc_insertion_point(module_scope)
